@@ -116,7 +116,7 @@ class Docstring:
         self.parser: Parser | None = parser
         self.parser_options: dict[str, Any] = parser_options or {}
 
-    def __bool__(self):
+    def __bool__(self) -> bool:
         return bool(self.value)
 
     @cached_property
@@ -663,7 +663,7 @@ class Object(GetMembersMixin, SetMembersMixin, ObjectAliasMixin):
         if self.parent is None:
             # could be a built-in
             raise NameResolutionError(f"{name} could not be resolved in the scope of {self.path}")
-        if name == self.parent.name:
+        if name == self.parent.name and not self.parent.is_module:
             return self.parent.path
         return self.parent.resolve(name)
 
